@@ -1,8 +1,11 @@
 """ Model for output of PV data """
-from xarray.ufuncs import isinf, isnan
+
+import logging
 
 from nowcasting_dataset.data_sources.datasource_output import DataSourceOutput
 
+logger = logging.getLogger(__name__)
+
 
 class PV(DataSourceOutput):
     """ Class to store PV data as a xr.Dataset with some validation """
@@ -12,10 +15,9 @@ class PV(DataSourceOutput):
 
     @classmethod
     def model_validation(cls, v):
-        """ Check that all values are not Nan, Infinite, or < 0."""
-        assert (~isnan(v.data)).all(), "Some pv data values are NaNs"
-        assert (~isinf(v.data)).all(), "Some pv data values are Infinite"
-        assert (v.data >= 0).all(), "Some pv data values are below 0"
+        """ Check that all values are non NaNs """
+        v.check_nan_and_inf(data=v.data)
+        v.check_dataset_greater_than_or_equal_to(data=v.data, min_value=0)
 
         assert v.time is not None
         assert v.x_coords is not None
