@@ -1,10 +1,12 @@
 """ Model for output of satellite data """
 from __future__ import annotations
 
-from xarray.ufuncs import isinf, isnan
+import logging
 
 from nowcasting_dataset.data_sources.datasource_output import DataSourceOutput
 
+logger = logging.getLogger(__name__)
+
 
 class Satellite(DataSourceOutput):
     """ Class to store satellite data as a xr.Dataset with some validation """
@@ -14,8 +16,8 @@ class Satellite(DataSourceOutput):
 
     @classmethod
     def model_validation(cls, v):
-        """ Check that all values are not NaN, Infinite, or -1."""
-        assert (~isnan(v.data)).all(), "Some satellite data values are NaNs"
-        assert (~isinf(v.data)).all(), "Some satellite data values are Infinite"
-        assert (v.data != -1).all(), "Some satellite data values are -1's"
+        """ Check that all values are non negative """
+        v.check_nan_and_inf(data=v.data)
+        # put this validation back in when issue is done
+        v.check_dataset_not_equal(data=v.data, value=-1, raise_error=False)
         return v
