@@ -1,4 +1,5 @@
 """ Loading Raw data """
+import logging
 from dataclasses import dataclass
 from datetime import datetime
 from numbers import Number
@@ -14,6 +15,8 @@ from nowcasting_dataset.data_sources.sun.raw_data_load_save import load_from_zar
 from nowcasting_dataset.data_sources.sun.sun_model import Sun
 from nowcasting_dataset.dataset.xr_utils import convert_data_array_to_dataset
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class SunDataSource(DataSource):
@@ -85,6 +88,9 @@ class SunDataSource(DataSource):
         return Sun(sun)
 
     def _load(self):
+
+        logger.info(f"Loading Sun data from {self.zarr_path}")
+
         self.azimuth, self.elevation = load_from_zarr(
             zarr_path=self.zarr_path, start_dt=self.start_dt, end_dt=self.end_dt
         )
